==> RPA_1.12.0.tar.gz: RPA/man/online.quantile.Rd <==
\name{online.quantile}
\alias{online.quantile}
\alias{qnorm.basis.online}

\title{Quantile normalization tools for online preprocessing.}
\description{Estimate quantiles for quantile normalization based on subset of the data (random, or specified by the user).}
\usage{
online.quantile(abatch, n)
qnorm.basis.online(cel.files, bg.method = "rma", cdf = NULL,
save.batches = FALSE, batch.size = 2, verbose = TRUE)
}
\arguments{
  \item{abatch}{AffyBatch}
  \item{n}{Numeric: number of random samples to use to define quantile basis. Vector: specify samples to be used in quantile basis calculation.}
  \item{cel.files}{List or vector of CEL files to process. Can also be a
  list of batches, each batch containing a vector of CEL files}
  \item{bg.method}{Background correction method}
  \item{cdf}{Optional. CDF file for alternative probeset definitions}
  \item{save.batches}{Logical. If TRUE, save results for each batch into file
  with batchname.RData where 'batchname' is picked from the batch
  identifiers in the batch list (as given by get.batches function).}
  \item{batch.size}{Batch size}
  \item{verbose}{Print progress information}
}
\details{"online.quantile": Ordinary quantile normalization is
  exhaustively memory-consuming in alrge data sets. Then the quantiles
  can be calculated based on subset of the data to allow efficient
  normalization. This function can also be used to investigate effect of
  subset size to convergence of the quantile estimates;
  "qnorm.basis.online": sweeps through the data in batches to calculate
  the basis for quantile normalization (average over sorted profiles).}
\value{"online.quantile": AffyBatch; "qnorm.basis.online": a vector
  containing the basis for quantile normalization.}
\references{See citation("RPA").}
\author{Leo Lahti \email{leo.lahti@iki.fi}}
\seealso{RPA.preprocess}
\examples{
#
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ utilities }

==> RPA_1.14.0.tar.gz: RPA/man/online.quantile.Rd <==
\name{online.quantile}
\alias{online.quantile}
\alias{qnorm.basis.online}

\title{Quantile normalization tools for online preprocessing.}
\description{Estimate quantiles for quantile normalization based on subset of the data (random, or specified by the user).}
\usage{
online.quantile(abatch, n)
qnorm.basis.online(cel.files, bg.method = "rma", cdf = NULL,
save.batches = FALSE, batch.size = 2, verbose = TRUE, save.batches.dir = ".", unique.run.identifier = NULL)
}
\arguments{
  \item{abatch}{AffyBatch}
  \item{n}{Numeric: number of random samples to use to define quantile basis. Vector: specify samples to be used in quantile basis calculation.}
  \item{cel.files}{List or vector of CEL files to process. Can also be a
  list of batches, each batch containing a vector of CEL files}
  \item{bg.method}{Background correction method}
  \item{cdf}{Optional. CDF file for alternative probeset definitions}
  \item{save.batches}{Logical. If TRUE, save results for each batch into file
  with batchname.RData where 'batchname' is picked from the batch
  identifiers in the batch list (as given by get.batches function).}
  \item{batch.size}{Batch size}
  \item{verbose}{Print progress information}
  \item{save.batches.dir}{Specify the output directory for temporary batch saves.}
  \item{unique.run.identifier}{Define identifier for this run for naming the temporary batch files. By default, a random id is generated.}
}
\details{"online.quantile": Ordinary quantile normalization is
  exhaustively memory-consuming in alrge data sets. Then the quantiles
  can be calculated based on subset of the data to allow efficient
  normalization. This function can also be used to investigate effect of
  subset size to convergence of the quantile estimates;
  "qnorm.basis.online": sweeps through the data in batches to calculate
  the basis for quantile normalization (average over sorted profiles).}
\value{"online.quantile": AffyBatch; "qnorm.basis.online": a vector
  containing the basis for quantile normalization.}
\references{See citation("RPA").}
\author{Leo Lahti \email{leo.lahti@iki.fi}}
\seealso{RPA.preprocess}
\examples{
#
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ utilities }
